@@ -245,7 +245,7 @@ fn monitor_thread(
     handle
 }
 
-fn unbox<T>(value: Box<T>) -> T {
+pub fn unbox<T>(value: Box<T>) -> T {
     *value
 }
 
